==> MBrane-1.0.8.crate: MBrane-1.0.8/tests/TSVector2DTest.rs <==
#![allow(non_snake_case)]

extern crate rand;
extern crate MBrane;

use rand::Rng;
use MBrane::ts::Vector2D::*;

#[test]
fn vector2d_initialization() {
    let mut rng = rand::thread_rng();

    let rx = rng.gen::<f64>();
    let ry = rng.gen::<f64>();

    let vector = Vector2D { X: rx, Y: ry };

    assert_eq!(rx, vector.X);
    assert_eq!(ry, vector.Y);
}

#[test]
fn vector2d_new_initialization() {
    let mut rng = rand::thread_rng();

    let rx = rng.gen::<f64>();
    let ry = rng.gen::<f64>();

    let vector = Vector2D { X: rx, Y: ry };
    let new_vector = vector.New(rx, ry);

    assert_eq!(rx, new_vector.X);
    assert_eq!(ry, new_vector.Y);
}

#[test]
fn vector2d_magnitude() {
    let mut rng = rand::thread_rng();

    let rx = rng.gen::<f64>();
    let ry = rng.gen::<f64>();

    let rresult = ((rx * rx) + (ry * ry)).sqrt();

    let vector = Vector2D { X: rx, Y: ry };

    let result: f64 = vector.Magnitude();

    assert_eq!(rresult, result);
}

#[test]
fn vector2d_normalization() {
    let mut rng = rand::thread_rng();

    let rx = rng.gen::<f64>();
    let ry = rng.gen::<f64>();

    let rxres = rx / ((rx * rx) + (ry * ry)).sqrt();
    let ryres = ry / ((rx * rx) + (ry * ry)).sqrt();

    let vector = Vector2D { X: rx, Y: ry };

    let result = vector.Normalize();

    assert_eq!(rxres, result.X);
    assert_eq!(ryres, result.Y);
}

#[test]
fn vector2d_self_normalization() {
    let mut rng = rand::thread_rng();

    let rx = rng.gen::<f64>();
    let ry = rng.gen::<f64>();

    let rxres = rx / ((rx * rx) + (ry * ry)).sqrt();
    let ryres = ry / ((rx * rx) + (ry * ry)).sqrt();

    let mut vector = Vector2D { X: rx, Y: ry };

    vector.SelfNormalize();

    assert_eq!(rxres, vector.X);
    assert_eq!(ryres, vector.Y);
}

#[test]
fn vector2d_dot_product() {
    let mut rng = rand::thread_rng();

    let rx_lhs = rng.gen::<f64>();
    let ry_lhs = rng.gen::<f64>();

    let rx_rhs = rng.gen::<f64>();
    let ry_rhs = rng.gen::<f64>();

    let result = (rx_lhs * rx_rhs) + (ry_lhs * ry_rhs);

    let vector_lhs = Vector2D {
        X: rx_lhs,
        Y: ry_lhs,
    };
    let vector_rhs = Vector2D {
        X: rx_rhs,
        Y: ry_rhs,
    };

    assert_eq!(result, vector_lhs.Dot(vector_rhs));
}

#[test]
fn vector2d_addition() {
    let mut rng = rand::thread_rng();

    let rx_lhs = rng.gen::<f64>();
    let ry_lhs = rng.gen::<f64>();

    let rx_rhs = rng.gen::<f64>();
    let ry_rhs = rng.gen::<f64>();

    let rx_result = rx_lhs + rx_rhs;
    let ry_result = ry_lhs + ry_rhs;

    let lhs = Vector2D {
        X: rx_lhs,
        Y: ry_lhs,
    };
    let rhs = Vector2D {
        X: rx_rhs,
        Y: ry_rhs,
    };

    let result = lhs + rhs;

    assert_eq!(rx_result, result.X);
    assert_eq!(ry_result, result.Y);
}

#[test]
fn vector2d_substraction() {
    let mut rng = rand::thread_rng();

    let rx_lhs = rng.gen::<f64>();
    let ry_lhs = rng.gen::<f64>();

    let rx_rhs = rng.gen::<f64>();
    let ry_rhs = rng.gen::<f64>();

    let rx_result = rx_lhs - rx_rhs;
    let ry_result = ry_lhs - ry_rhs;

    let lhs = Vector2D {
        X: rx_lhs,
        Y: ry_lhs,
    };
    let rhs = Vector2D {
        X: rx_rhs,
        Y: ry_rhs,
    };

    let result = lhs - rhs;

    assert_eq!(rx_result, result.X);
    assert_eq!(ry_result, result.Y);
}

#[test]
fn vector2d_multiplication() {
    let mut rng = rand::thread_rng();

    let rx_lhs = rng.gen::<f64>();
    let ry_lhs = rng.gen::<f64>();

    let rx_rhs = rng.gen::<f64>();
    let ry_rhs = rng.gen::<f64>();

    let rx_result = rx_lhs * rx_rhs;
    let ry_result = ry_lhs * ry_rhs;

    let lhs = Vector2D {
        X: rx_lhs,
        Y: ry_lhs,
    };
    let rhs = Vector2D {
        X: rx_rhs,
        Y: ry_rhs,
    };

    let result = lhs * rhs;

    assert_eq!(rx_result, result.X);
    assert_eq!(ry_result, result.Y);
}

#[test]
fn vector2d_division() {
    let mut rng = rand::thread_rng();

    let rx_lhs = rng.gen::<f64>();
    let ry_lhs = rng.gen::<f64>();

    let rx_rhs = rng.gen::<f64>();
    let ry_rhs = rng.gen::<f64>();

    let rx_result = rx_lhs / rx_rhs;
    let ry_result = ry_lhs / ry_rhs;

    let lhs = Vector2D {
        X: rx_lhs,
        Y: ry_lhs,
    };
    let rhs = Vector2D {
        X: rx_rhs,
        Y: ry_rhs,
    };

    let result = lhs / rhs;

    assert_eq!(rx_result, result.X);
    assert_eq!(ry_result, result.Y);
}

==> MBrane-1.0.10.crate: MBrane-1.0.10/tests/TSVector2DTest.rs <==
#![allow(non_snake_case)]

extern crate rand;
extern crate MBrane;

use rand::Rng;
use MBrane::ts::Vector2D::*;

#[test]
fn vector2d_initialization() {
    let mut rng = rand::thread_rng();

    let rx = rng.gen::<f64>();
    let ry = rng.gen::<f64>();

    let vector = Vector2D { X: rx, Y: ry };

    assert_eq!(rx, vector.X);
    assert_eq!(ry, vector.Y);
}

#[test]
fn vector2d_new_initialization() {
    let mut rng = rand::thread_rng();

    let rx = rng.gen::<f64>();
    let ry = rng.gen::<f64>();

    let vector = Vector2D::new(rx, ry);

    assert_eq!(rx, vector.X);
    assert_eq!(ry, vector.Y);
}

#[test]
fn vector2d_magnitude() {
    let mut rng = rand::thread_rng();

    let rx = rng.gen::<f64>();
    let ry = rng.gen::<f64>();

    let rresult = ((rx * rx) + (ry * ry)).sqrt();

    let vector = Vector2D::new(rx, ry);

    assert_eq!(rresult, vector.magnitude());
}

#[test]
fn vector2d_normalization() {
    let mut rng = rand::thread_rng();

    let rx = rng.gen::<f64>();
    let ry = rng.gen::<f64>();

    let rxres = rx / ((rx * rx) + (ry * ry)).sqrt();
    let ryres = ry / ((rx * rx) + (ry * ry)).sqrt();

    let vector = Vector2D::new(rx, ry);

    let result = vector.normalize();

    assert_eq!(rxres, result.X);
    assert_eq!(ryres, result.Y);
}

#[test]
fn vector2d_self_normalization() {
    let mut rng = rand::thread_rng();

    let rx = rng.gen::<f64>();
    let ry = rng.gen::<f64>();

    let rxres = rx / ((rx * rx) + (ry * ry)).sqrt();
    let ryres = ry / ((rx * rx) + (ry * ry)).sqrt();

    let mut vector = Vector2D::new(rx, ry);

    vector.self_normalize();

    assert_eq!(rxres, vector.X);
    assert_eq!(ryres, vector.Y);
}

#[test]
fn vector2d_dot_product() {
    let mut rng = rand::thread_rng();

    let rx_lhs = rng.gen::<f64>();
    let ry_lhs = rng.gen::<f64>();

    let rx_rhs = rng.gen::<f64>();
    let ry_rhs = rng.gen::<f64>();

    let result = (rx_lhs * rx_rhs) + (ry_lhs * ry_rhs);

    let vector_lhs = Vector2D::new(rx_lhs, ry_lhs);
    let vector_rhs = Vector2D::new(rx_rhs, ry_rhs);

    let res = vector_lhs | vector_rhs;

    assert_eq!(result, res);
}

#[test]
fn vector2d_addition() {
    let mut rng = rand::thread_rng();

    let rx_lhs = rng.gen::<f64>();
    let ry_lhs = rng.gen::<f64>();

    let rx_rhs = rng.gen::<f64>();
    let ry_rhs = rng.gen::<f64>();

    let rx_result = rx_lhs + rx_rhs;
    let ry_result = ry_lhs + ry_rhs;

    let lhs = Vector2D::new(rx_lhs, ry_lhs);
    let rhs = Vector2D::new(rx_rhs, ry_rhs);

    let result = lhs + rhs;

    assert_eq!(rx_result, result.X);
    assert_eq!(ry_result, result.Y);
}

#[test]
fn vector2d_substraction() {
    let mut rng = rand::thread_rng();

    let rx_lhs = rng.gen::<f64>();
    let ry_lhs = rng.gen::<f64>();

    let rx_rhs = rng.gen::<f64>();
    let ry_rhs = rng.gen::<f64>();

    let rx_result = rx_lhs - rx_rhs;
    let ry_result = ry_lhs - ry_rhs;

    let lhs = Vector2D::new(rx_lhs, ry_lhs);
    let rhs = Vector2D::new(rx_rhs, ry_rhs);

    let result = lhs - rhs;

    assert_eq!(rx_result, result.X);
    assert_eq!(ry_result, result.Y);
}

#[test]
fn vector2d_multiplication() {
    let mut rng = rand::thread_rng();

    let rx_lhs = rng.gen::<f64>();
    let ry_lhs = rng.gen::<f64>();

    let rx_rhs = rng.gen::<f64>();
    let ry_rhs = rng.gen::<f64>();

    let rx_result = rx_lhs * rx_rhs;
    let ry_result = ry_lhs * ry_rhs;

    let lhs = Vector2D::new(rx_lhs, ry_lhs);
    let rhs = Vector2D::new(rx_rhs, ry_rhs);

    let result = lhs * rhs;

    assert_eq!(rx_result, result.X);
    assert_eq!(ry_result, result.Y);
}

#[test]
fn vector2d_division() {
    let mut rng = rand::thread_rng();

    let rx_lhs = rng.gen::<f64>();
    let ry_lhs = rng.gen::<f64>();

    let rx_rhs = rng.gen::<f64>();
    let ry_rhs = rng.gen::<f64>();

    let rx_result = rx_lhs / rx_rhs;
    let ry_result = ry_lhs / ry_rhs;

    let lhs = Vector2D::new(rx_lhs, ry_lhs);
    let rhs = Vector2D::new(rx_rhs, ry_rhs);

    let result = lhs / rhs;

    assert_eq!(rx_result, result.X);
    assert_eq!(ry_result, result.Y);
}

#[test]
fn vector2d_dot() {
    let mut rng = rand::thread_rng();

    let rx_lhs = rng.gen::<f64>();
    let ry_lhs = rng.gen::<f64>();

    let rx_rhs = rng.gen::<f64>();
    let ry_rhs = rng.gen::<f64>();

    let result = (rx_lhs * rx_rhs) + (ry_lhs * ry_rhs);

    let lhs = Vector2D::new(rx_lhs, ry_lhs);
    let rhs = Vector2D::new(rx_rhs, ry_rhs);

    let res = lhs | rhs;

    assert_eq!(result, res);
}
